=================
Stoner-PythonCode
=================
.. toctree::
   :maxdepth: 2

.. include:: readme.rst

User Guide
==========

.. toctree::
   :maxdepth: 2

   User Guide <UserGuide/ugindex>

Package Documentatuion
======================
.. toctree::
   :maxdepth: 2

   Module Api Documentation <Stoner>

